readfish console scripts
========================

``readfish`` is a set of scripts that are accessed as sub-commands.
These scripts are primarily aimed at implementing Adaptive Sampling (also known as Read Until or selective sequencing) for Oxford Nanopore Sequencers.


Commands
--------


``readfish targets``
********************

.. automodule:: readfish.entry_points.targets


``readfish unblock-all``
************************

.. automodule:: readfish.entry_points.unblock_all


``readfish validate``
*********************

.. automodule:: readfish.entry_points.validate

``readfish stats``
*********************

.. automodule:: readfish.entry_points.stats
